@@ -52,6 +52,8 @@ int preGradeTimes[] = {
 EntryFilter::EntryFilter(KEduVocDocument* doc, QObject * parent)
     : QObject(parent)
     , m_doc(doc)
+    , m_fromTranslation(Prefs::knownLanguage())
+    , m_toTranslation(Prefs::learningLanguage())
     , m_dialog(0)
 {
     if (Prefs::practiceMode() == Prefs::EnumPracticeMode::ConjugationPractice) {
@@ -61,7 +63,7 @@ EntryFilter::EntryFilter(KEduVocDocument* doc, QObject * parent)
         qDebug() << "Tenses" << m_tenses;
     }
 }
-
+/*
 static void debugEntry(const QString &comment, KEduVocExpression *vocexp,
                        KEduVocTranslation *from, KEduVocTranslation *to)
 {
@@ -69,7 +71,7 @@ static void debugEntry(const QString &comment, KEduVocExpression *vocexp,
 
     qDebug() << comment << "from" << from->text() << "to" << to->text();
 }
-
+*/
 QList<TestEntry*> EntryFilter::entries(bool showDialog)
 {
     switch (Prefs::practiceDirection()) {
@@ -111,9 +113,10 @@ QList<TestEntry*> EntryFilter::entries(bool showDialog)
         }
 
 	//qDebug() << "Filter for " << m_fromTranslation << " to " << m_toTranslation;
-        expireEntries(pass);
 
         collectEntries(pass);
+        expireEntries(pass);
+        setupFilteredEntries(pass);
     }
 
     static QString noEntriesError =
@@ -274,7 +277,8 @@ void EntryFilter::expireEntries(int setNo)
                 entry->translation(m_toTranslation)->decGrade();
 
                 // prevent from endless dropping
-                entry->translation(m_toTranslation)->setPracticeDate(QDateTime::currentDateTime().addSecs(-Prefs::expireItem(grade - 2)));
+                // use blockItem() time to prevent blocking after expiring
+                entry->translation(m_toTranslation)->setPracticeDate(QDateTime::currentDateTime().addSecs(-Prefs::blockItem(grade - 1)));
                 counter++;
             }
         }
@@ -301,7 +305,10 @@ void EntryFilter::collectEntries(int setNo)
         }
     }
     */
+}
 
+void EntryFilter::setupFilteredEntries(int setNo)
+{
     lessonEntries(setNo);
     wordTypeEntries(setNo);
     blockedEntries(setNo);
@@ -310,7 +317,6 @@ void EntryFilter::collectEntries(int setNo)
     minMaxGradeEntries(setNo);
 }
 
-
 void EntryFilter::lessonEntries(int setNo)
 {
     foreach(KEduVocExpression * entry, m_entries[setNo]) {
@@ -634,6 +640,8 @@ QList< TestEntry* > EntryFilter::conjugationTestEntries(bool ignoreBlocked) cons
                         if (mode == M_SEPARATE) {
                             TestEntry* testEntry = new TestEntry(entry);
                             testEntry->setConjugationTense(tense);
+                            testEntry->setLanguageTo(m_toTranslation);
+                            testEntry->setLanguageFrom(m_fromTranslation);
                             QList<KEduVocWordFlags> list;
                             list << pronoun;
                             testEntry->setConjugationPronouns(list);
@@ -646,6 +654,8 @@ QList< TestEntry* > EntryFilter::conjugationTestEntries(bool ignoreBlocked) cons
                     TestEntry* testEntry = new TestEntry(entry);
                     testEntry->setConjugationTense(tense);
                     testEntry->setConjugationPronouns(pronouns);
+                    testEntry->setLanguageTo(m_toTranslation);
+                    testEntry->setLanguageFrom(m_fromTranslation);
                     randomizedInsert(testEntries, testEntry);
                 }
             }
