@@ -41,27 +41,27 @@ ConfigurePracticeDialog::ConfigurePracticeDialog(KEduVocDocument *doc, QWidget *
     m_generalPracticeOptions = new GeneralPracticeOptions(this);
     addPage(m_generalPracticeOptions,
             i18nc("@title:group Configure general settings for practicing vocabulary, short title in config dialog.", "General"),
-            "general-setup", i18nc("Configure general settings for practicing vocabulary.", "General Practice Settings"),
+            QStringLiteral("general-setup"), i18nc("Configure general settings for practicing vocabulary.", "General Practice Settings"),
             true);
 
     m_blockOptions = new BlockOptions(this);
-    addPage(m_blockOptions, i18nc("@title:group vocabulary can be set to be blocked for a certain amount of time", "Blocking"), "cards-block", i18n("Blocking Settings"), true);
+    addPage(m_blockOptions, i18nc("@title:group vocabulary can be set to be blocked for a certain amount of time", "Blocking"), QStringLiteral("cards-block"), i18n("Blocking Settings"), true);
 
     m_thresholdOptions = new ThresholdOptions(doc, this);
-    addPage(m_thresholdOptions, i18nc("@title:group ignore vocabulary based on some properties like word type", "Thresholds"), "practice-setup", i18n("Threshold Settings"), true);
+    addPage(m_thresholdOptions, i18nc("@title:group ignore vocabulary based on some properties like word type", "Thresholds"), QStringLiteral("practice-setup"), i18n("Threshold Settings"), true);
 
     m_specificPracticeOptions = new SpecificPracticeOptions(this);
-    addPage(m_specificPracticeOptions, i18nc("@title:group Configure specific settings for practicing vocabulary, short title in config dialog.", "Specific"), "specific-setup", i18nc("Configure specific settings for practicing vocabulary.", "Specific Practice Settings"), true);
+    addPage(m_specificPracticeOptions, i18nc("@title:group Configure specific settings for practicing vocabulary, short title in config dialog.", "Specific"), QStringLiteral("specific-setup"), i18nc("Configure specific settings for practicing vocabulary.", "Specific Practice Settings"), true);
 
-    setHelp(QString(), "parley");
+    setHelp(QString(), QStringLiteral("parley"));
 
-    KConfigGroup cg(KSharedConfig::openConfig("parleyrc"), "ConfigurePracticeDialog");
+    KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral("parleyrc")), "ConfigurePracticeDialog");
     this->resize( cg.readEntry("width",100 ), cg.readEntry("height",100 ) );
 }
 
 ConfigurePracticeDialog::~ConfigurePracticeDialog()
 {
-    KConfigGroup cg(KSharedConfig::openConfig("parleyrc"), "ConfigurePracticeDialog");
+    KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral("parleyrc")), "ConfigurePracticeDialog");
     cg.writeEntry("width",  this->size().width() );
     cg.writeEntry("height",  this->size().height() );
 }
